@@ -33,8 +33,11 @@ CoARequest = 43
 CoAACK = 44
 CoANAK = 45
 
+# Use cryptographic-safe random generator as provided by the OS.
+random_generator = random.SystemRandom()
+
 # Current ID
-CurrentID = random.randrange(1, 255)
+CurrentID = random_generator.randrange(1, 255)
 
 
 class PacketError(Exception):
@@ -57,8 +60,7 @@ class Packet(dict):
     :obj:`AuthPacket` or :obj:`AcctPacket` classes.
     """
 
-    def __init__(self, code=0, id=None, secret=six.b(''), authenticator=None,
-            **attributes):
+    def __init__(self, code=0, id=None, secret=six.b(''), authenticator=None, **attributes):
         """Constructor
 
         :param dict:   RADIUS dictionary
@@ -114,22 +116,38 @@ class Packet(dict):
             return tools.DecodeAttr(attr.type, value)
 
     def _EncodeValue(self, attr, value):
+        result = ''
         if attr.values.HasForward(value):
-            return attr.values.GetForward(value)
+            result = attr.values.GetForward(value)
         else:
-            return tools.EncodeAttr(attr.type, value)
+            result = tools.EncodeAttr(attr.type, value)
+
+        if attr.encrypt == 2:
+            # salt encrypt attribute
+            result = self.SaltCrypt(result)
+
+        return result
 
     def _EncodeKeyValues(self, key, values):
         if not isinstance(key, str):
             return (key, values)
 
+        key, _, tag = key.partition(":")
+
         attr = self.dict.attributes[key]
         if attr.vendor:
             key = (self.dict.vendors.GetForward(attr.vendor), attr.code)
         else:
             key = attr.code
 
-        return (key, [self._EncodeValue(attr, v) for v in values])
+        if tag:
+            tag = struct.pack('B', int(tag))
+            if attr.type == "integer":
+                return (key, [tag + self._EncodeValue(attr, v)[1:] for v in values])
+            else:
+                return (key, [tag + self._EncodeValue(attr, v) for v in values])
+        else:
+            return (key, [self._EncodeValue(attr, v) for v in values])
 
     def _EncodeKey(self, key):
         if not isinstance(key, str):
@@ -157,10 +175,13 @@ class Packet(dict):
         :param value: value
         :type value:  depends on type of attribute
         """
-        (key, value) = self._EncodeKeyValues(key, [value])
-        value = value[0]
-
-        self.setdefault(key, []).append(value)
+        if isinstance(value, list):
+            (key, value) = self._EncodeKeyValues(key, value)
+            self.setdefault(key, []).extend(value)
+        else:
+            (key, value) = self._EncodeKeyValues(key, [value])
+            value = value[0]
+            self.setdefault(key, []).append(value)
 
     def __getitem__(self, key):
         if not isinstance(key, six.string_types):
@@ -208,7 +229,7 @@ class Packet(dict):
 
         data = []
         for i in range(16):
-            data.append(random.randrange(0, 256))
+            data.append(random_generator.randrange(0, 256))
         if six.PY3:
             return bytes(data)
         else:
@@ -223,7 +244,7 @@ class Packet(dict):
         :rtype:  integer
 
         """
-        return random.randrange(0, 256)
+        return random_generator.randrange(0, 256)
 
     def ReplyPacket(self):
         """Create a ready-to-transmit authentication reply packet.
@@ -235,7 +256,7 @@ class Packet(dict):
         :rtype:  string
         """
         assert(self.authenticator)
-        assert(self.secret)
+        assert(self.secret is not None)
 
         attr = self._PktEncodeAttributes()
         header = struct.pack('!BBH', self.code, self.id, (20 + len(attr)))
@@ -278,14 +299,21 @@ class Packet(dict):
         # Check if this packet is long enough to be in the
         # RFC2865 recommended form
         if len(data) < 6:
-            return (26, data)
+            return [(26, data)]
 
         (vendor, type, length) = struct.unpack('!LBB', data[:6])[0:3]
-        # Another sanity check
-        if len(data) != length + 4:
-            return (26, data)
 
-        return ((vendor, type), data[6:])
+        tlvs = [((vendor, type), data[6:length+4])]
+
+        sumlength = 4 + length
+        while len(data) > sumlength:
+            try:
+                type, length = struct.unpack('!BB', data[sumlength:sumlength+2])[0:2]
+            except:
+                return [(26, data)]
+            tlvs.append(((vendor, type), data[sumlength+2:sumlength+length]))
+            sumlength += length
+        return tlvs
 
     def DecodePacket(self, packet):
         """Initialize the object from raw packet data.  Decode a packet as
@@ -319,11 +347,54 @@ class Packet(dict):
 
             value = packet[2:attrlen]
             if key == 26:
-                (key, value) = self._PktDecodeVendorAttribute(value)
+                for (key, value) in self._PktDecodeVendorAttribute(value):
+                    self.setdefault(key, []).append(value)
+            else:
+                self.setdefault(key, []).append(value)
 
-            self.setdefault(key, []).append(value)
             packet = packet[attrlen:]
 
+    def SaltCrypt(self, value):
+        """Salt Encryption
+
+        :param value:    plaintext value
+        :type password:  unicode string
+        :return:         obfuscated version of the value
+        :rtype:          binary string
+        """
+
+        if isinstance(value, six.text_type):
+            value = value.encode('utf-8')
+
+        if self.authenticator is None:
+            # self.authenticator = self.CreateAuthenticator()
+            self.authenticator = 16 * six.b('\x00')
+
+        salt = struct.pack('!H', random_generator.randrange(0, 65535))
+        salt = chr(ord(salt[0]) | 1 << 7)+salt[1]
+
+        length = struct.pack("B", len(value))
+        buf = length + value
+        if len(buf) % 16 != 0:
+            buf += six.b('\x00') * (16 - (len(buf) % 16))
+
+        result = six.b(salt)
+
+        last = self.authenticator + salt
+        while buf:
+            hash = md5_constructor(self.secret + last).digest()
+            if six.PY3:
+                for i in range(16):
+                    result += bytes((hash[i] ^ buf[i],))
+            else:
+                for i in range(16):
+                    result += chr(ord(hash[i]) ^ ord(buf[i]))
+
+            last = result[-16:]
+            buf = buf[16:]
+
+        return result
+
 
 class AuthPacket(Packet):
     def __init__(self, code=AccessRequest, id=None, secret=six.b(''),
@@ -447,6 +518,34 @@ class AuthPacket(Packet):
 
         return result
 
+    def VerifyChapPasswd(self, userpwd):
+        """ Verify RADIUS ChapPasswd
+
+        :param userpwd: plaintext password
+        :type userpwd:  str
+        :return:        is verify ok
+        :rtype:         bool
+        """
+
+        if not self.authenticator:
+            self.authenticator = self.CreateAuthenticator()
+
+        if isinstance(userpwd, six.text_type):
+            userpwd = userpwd.strip().encode('utf-8')
+
+        chap_password = tools.DecodeOctets(self.get(3)[0])
+        if len(chap_password) != 17:
+            return False
+
+        chapid = chap_password[0]
+        password = chap_password[1:]
+
+        challenge = self.authenticator
+        if 'CHAP-Challenge' in self:
+            challenge = self['CHAP-Challenge'][0]
+
+        return password == md5_constructor("%s%s%s" % (chapid, userpwd, challenge)).digest()
+
 
 class AcctPacket(Packet):
     """RADIUS accounting packets. This class is a specialization
@@ -511,6 +610,68 @@ class AcctPacket(Packet):
             + self.secret).digest()
         return header + self.authenticator + attr
 
+class CoAPacket(Packet):
+    """RADIUS CoA packets. This class is a specialization
+    of the generic :obj:`Packet` class for CoA packets.
+    """
+
+    def __init__(self, code=CoARequest, id=None, secret=six.b(''),
+            authenticator=None, **attributes):
+        """Constructor
+
+        :param dict:   RADIUS dictionary
+        :type dict:    pyrad.dictionary.Dictionary class
+        :param secret: secret needed to communicate with a RADIUS server
+        :type secret:  string
+        :param id:     packet identifaction number
+        :type id:      integer (8 bits)
+        :param code:   packet type code
+        :type code:    integer (8bits)
+        :param packet: raw packet to decode
+        :type packet:  string
+        """
+        Packet.__init__(self, code, id, secret, authenticator, **attributes)
+        if 'packet' in attributes:
+            self.raw_packet = attributes['packet']
+
+    def CreateReply(self, **attributes):
+        """Create a new packet as a reply to this one. This method
+        makes sure the authenticator and secret are copied over
+        to the new instance.
+        """
+        return CoAPacket(CoAACK, self.id,
+            self.secret, self.authenticator, dict=self.dict,
+            **attributes)
+
+    def VerifyCoARequest(self):
+        """Verify request authenticator.
+
+        :return: True if verification failed else False
+        :rtype: boolean
+        """
+        assert(self.raw_packet)
+        hash = md5_constructor(self.raw_packet[0:4] + 16 * six.b('\x00') +
+                self.raw_packet[20:] + self.secret).digest()
+        return hash == self.authenticator
+
+    def RequestPacket(self):
+        """Create a ready-to-transmit CoA request packet.
+        Return a RADIUS packet which can be directly transmitted
+        to a RADIUS server.
+
+        :return: raw packet
+        :rtype:  string
+        """
+
+        attr = self._PktEncodeAttributes()
+
+        if self.id is None:
+            self.id = self.CreateID()
+
+        header = struct.pack('!BBH', self.code, self.id, (20 + len(attr)))
+        self.authenticator = md5_constructor(header[0:4] + 16 * six.b('\x00') + attr
+            + self.secret).digest()
+        return header + self.authenticator + attr
 
 def CreateID():
     """Generate a packet ID.
